@@ -284,6 +284,11 @@ class ObjectIdentifier(unittest.TestCase):
         assert univ.ObjectIdentifier((1,3,6))==(1,3,6),'prettyIn() fails'
     def testInput3(self):
         assert univ.ObjectIdentifier(univ.ObjectIdentifier('1.3') + (6,))==(1,3,6),'prettyIn() fails'
+    def testUnicode(self):
+        s = '1.3.6'
+        if version_info[0] < 3:
+            s = s.decode()
+        assert univ.ObjectIdentifier(s) == (1,3,6), 'unicode init fails'
     def testTag(self):
         assert univ.ObjectIdentifier().getTagSet() == tag.TagSet(
             (),
